
/*
 * Astroblast 2000
 * Copyright (C) 2000 David Piott
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */


#include <stdio.h>
#include <stdlib.h>
#include <math.h>
#include "SDL.h"
#include "ab2t.h"
#include "font.h"   // SFont by Karl Bartel


SDL_Surface *AFont;
Uint32 Background;
int HARD=0;

char* itoa(int value)    /* integer to array */
{
	char ch[256];
	char *c;
	int digit, place, i;
	
	ch[0]=(char)(value%10+48);
	place=1;
	while ((digit=(value/(int)(pow(10,place))))>0) ch[place++]=(char)(digit%10+48);
	c=(char*)calloc(place+1,sizeof(char));	
	for (i=0;i<place;i++) c[i]=ch[place-i-1];
	c[place]=0;
	return c;
}	

int CheckContact(Thing *a, Thing *b)	
{
	
	SDL_Rect one, two;
	one.w=a->image->frame[0]->w;
	one.h=a->image->frame[0]->h;
	one.x=a->x-(one.w/2);
	one.y=a->y-(one.h/2);
	two.w=b->image->frame[0]->w;
	two.h=b->image->frame[0]->h;
	two.x=b->x-(two.w/2);
	two.y=b->y-(two.h/2);
	
	if (one.x+one.w/2>=two.x-one.w/2 &&
	    one.x+one.w/2<=two.x+two.w+one.w/2 &&
	    one.y+one.h/2>=two.y &&
	    one.y+one.h/2<=two.y+two.h) return 1;
		
	return 0;
}

	 	
void DestroyThing(Thing *todie)
{
	Thing *dead;
	if (Death!=NULL) dead=Death;  				// Sort of a death waiting room
	else {Death=todie; return;}
	Death=todie;
	
	if (dead->prev!=NULL) dead->prev->next=dead->next;
	if (dead->next!=NULL) dead->next->prev=dead->prev;
	free(dead);
}


Thing* CreateLMeteo(Thing* creator, int dir, int speed, int x, int y)
{
	Thing* newthing;
	if (DEBUG) printf("LittleMeteor\n");
	while (creator->next!=NULL) creator=creator->next; 				// goto the end of the list
	creator->next=(Thing*)calloc(1,sizeof(Thing));					
	newthing=creator->next;								
	newthing->prev=creator;
	newthing->next=NULL;
	newthing->health=100;
	newthing->type=LMETEO;
	newthing->dir=dir;
	newthing->speed=speed;
	newthing->x=x;
	newthing->y=y;
	newthing->update=UpdateLMeteo;
	newthing->move=Move;
	newthing->draw=Draw;
	newthing->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) newthing->image->frame[i]=Sprite[3];
	return newthing;
}
	
Thing* CreateBMeteo(Thing* creator, int dir, int speed, int x, int y)
{
	Thing* newthing;
	if (DEBUG) printf("BigMeteor\n");
	while (creator->next!=NULL) creator=creator->next; 				// goto the end of the list
	creator->next=(Thing*)calloc(1,sizeof(Thing));					
	newthing=creator->next;
	newthing->prev=creator;
	newthing->next=NULL;
	newthing->health=100;
	newthing->type=BMETEO;
	newthing->dir=dir;
	newthing->speed=speed;
	newthing->x=x;
	newthing->y=y;
	newthing->update=UpdateBMeteo;
	newthing->move=Move;
	newthing->draw=Draw;
	newthing->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) newthing->image->frame[i]=Sprite[2];
	return newthing;
}
	
Thing* CreateStar(Thing* creator, int dir, int speed, int x, int y)
{
	Thing *newthing, *temp;
	if (DEBUG) printf("Star\n");
	while (creator->prev!=NULL) creator=creator->prev; 				// goto the start of the list
	temp=creator->next;
	creator->next=(Thing*)calloc(1,sizeof(Thing));					
	newthing=creator->next;
	newthing->prev=creator;
	newthing->next=temp;
	newthing->health=100;
	newthing->type=STAR;
	newthing->dir=dir;
	newthing->speed=speed;
	newthing->x=x;
	newthing->y=y;
	newthing->update=UpdateStar;
	newthing->move=Move;
	newthing->draw=Draw;
	newthing->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) newthing->image->frame[i]=Sprite[i+8];
	if (temp!=NULL) temp->prev=newthing;
	return newthing;
}
	
Thing* CreateSeeker(Thing* creator, int dir, int speed, int x, int y)
{
	Thing* newthing;
	if (DEBUG) printf("Seeker\n");
	while (creator->next!=NULL) creator=creator->next; 				// goto the end of the list
	creator->next=(Thing*)calloc(1,sizeof(Thing));					
	newthing=creator->next;
	newthing->prev=creator;
	newthing->next=NULL;
	newthing->health=100;
	newthing->type=SEEKER;
	newthing->dir=dir;
	newthing->speed=speed;
	newthing->x=x;
	newthing->y=y;
	newthing->update=UpdateSeeker;
	newthing->move=Move;
	newthing->draw=Draw;
	newthing->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) newthing->image->frame[i]=Sprite[i+4];
	return newthing;
}
	
	
Thing* CreateBullet(Thing* creator, int dir, int speed, int x, int y)
{
	Thing* newthing;
	if (DEBUG) printf("Bullet\n");
	while (creator->next!=NULL) creator=creator->next; 				// goto the end of the list
	creator->next=(Thing*)calloc(1,sizeof(Thing));					
	newthing=creator->next;
	newthing->prev=creator;
	newthing->next=NULL;
	newthing->health=100;
	newthing->type=BULLET;
	newthing->dir=dir;
	newthing->speed=speed;
	newthing->x=x;
	newthing->y=y;
	newthing->update=UpdateBullet;
	newthing->move=Move;
	newthing->draw=Draw;
	newthing->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) newthing->image->frame[i]=Sprite[1];
	return newthing;
}
	

	
void UpdateLMeteo(Thing *t)
{
	
	if (t->health<=0)
	{
		Score+=20;
		DestroyThing(t);
		return;
	}
	
	if (CheckContact(t,Player)) 
	{
		Player->health-=100;
		DestroyThing(t);
		return;
	}
	if (t->y>GROUND)
	{
		if (Play) Score-=10;
		DestroyThing(t);
		return;
	}
	
}	
		
void UpdateBMeteo(Thing *t)
{
	
	if (t->health<=0)
	{
		Score+=10;
		CreateLMeteo(t,DOWNLEFT,t->speed,t->x-15,t->y-15);
		CreateLMeteo(t,DOWNRIGHT,t->speed,t->x+15,t->y+15);
		DestroyThing(t);
		return;
	}
	
	if (CheckContact(t,Player)) 
	{
		Player->health-=100;
		DestroyThing(t);
		return;
	}
	if (t->y>GROUND)
	{
		if (Play) Score-=5;
		DestroyThing(t);
		return;
	}
	
}	


		
void UpdateStar(Thing *t)
{
	
	if (t->health<=0)
	{
		Score+=80;
		DestroyThing(t);
		return;
	}
	
	if (CheckContact(t,Player)) 
	{
		Player->health-=100;
		DestroyThing(t);
		return;
	}
	if (t->y>GROUND)
	{
		Player->health-=100;
		DestroyThing(t);
		return;
	}
	
}	


		
void UpdateSeeker(Thing *t)
{
	
	if (t->health<=0)
	{
		Score+=100;  //Is this right?
		DestroyThing(t);
		return;
	}
	
	if (CheckContact(t,Player)) 
	{
		Player->health-=100;
		DestroyThing(t);
		return;
	}
	if (t->y>GROUND)
	{
		DestroyThing(t);
		return;
	}
	if (t->x<Player->x-50) t->dir=DOWNRIGHT;
	if (t->x>Player->x+50) t->dir=DOWNLEFT;
		
}	

		
void UpdateBullet(Thing *t)
{
	
	Thing *search;
	
	
	if (t->y<0||t->y>HEIGHT||t->x<0||t->x>WIDTH)
	{
		DestroyThing(t);
		return;
	}
	search=t;
	while (search->prev!=NULL) search=search->prev; 				// goto the start of the list
	while (search!=NULL)
	{
		if (CheckContact(t,search))
		{
			if (search->type!=PLAYER&&search->type!=BULLET)
			{
				search->health-=100;
				if (CRUSH)
				{
					(*search->update)(search);
					CreateBullet(Player,UPLEFT,F_SPEED,t->x,t->y);
					CreateBullet(Player,UPRIGHT,F_SPEED,t->x,t->y);
					CreateBullet(Player,DOWNLEFT,F_SPEED,t->x,t->y);
					CreateBullet(Player,DOWNRIGHT,F_SPEED,t->x,t->y);
				}			
				DestroyThing(t);
				return;
			}
		}
		search=search->next;
	}
		
}	

void KillAll(void)
{		
	Thing* erase;
		
	erase=Player->next;
	Player->next=NULL;
	if (erase!=NULL)
	{
		if (erase->next!=NULL) 
		{
			erase=erase->next;
			while(erase!=NULL)
			{
				free(erase->prev);
				erase=erase->next;
			}
		}
		else free(erase);
	}
}		


		
void UpdatePlayer(Thing *t)
{
	
	if (Play==0) return;
	if (t->health<=0)
	{
		Score-=Level*100; //Is this right?
		Lives--;
		Play=0;
		
		//KillAll();
		
		CreateLMeteo(Player,UP,F_SPEED,Player->x,Player->y);
		CreateLMeteo(Player,UPLEFT,F_SPEED,Player->x,Player->y);
		CreateLMeteo(Player,UPRIGHT,F_SPEED,Player->x,Player->y);
		
		Player->x=STARTX;
		Player->y=STARTY;
		Player->health=100;
		return;
	}
	
	
	if (t->x<MARGIN) t->x=MARGIN;
	if (t->x>WIDTH-MARGIN) t->x=WIDTH-MARGIN;
	if (t->y>STARTY) t->y=STARTY;
	if (t->y<0) t->y=0;
			
}	


void Move(Thing *t)
{
	switch (t->dir)        
	{
		case DOWN:
			t->y+=t->speed;
			break;
		case UP:
			t->y-=t->speed;
			break;
		case DOWNLEFT:
			t->y+=t->speed;
			t->x-=t->speed;
			break;
		case DOWNRIGHT:
			t->y+=t->speed;
			t->x+=t->speed;
			break;
		case RIGHT:
			t->x+=t->speed;
			break;
		case LEFT:
			t->x-=t->speed;
			break;
		case UPLEFT:
			t->y-=t->speed;
			t->x-=t->speed;
			break;
		case UPRIGHT:
			t->y-=t->speed;
			t->x+=t->speed;
			break;
		default:
			break;
			
	}
}

void Draw(Thing *t)
{
	SDL_Surface *frame;
	SDL_Rect area;
	
	if (t->type==PLAYER&&Play==0) return;
	
	frame=t->image->frame[CurrentFrame];
	area.w=frame->w;
	area.h=frame->h;
	area.x=t->x-(frame->w/2);
	area.y=t->y-(frame->h/2);
		
	SDL_BlitSurface(frame,NULL,Screen,&area);
}	

Thing* GotoStart(Thing* list)
{
	while (list->prev!=NULL) list=list->prev;
	return list;
}

void MainLoop(void)
{
	Thing* list=Player;
	char *_score, *_lives;
	int title=1;
	int updatetime, drawtime, movetime, shoottime;
	SDL_Event event;
	int done=0;
	int highscore=0;
	updatetime=0; drawtime=0; movetime=0; shoottime=0; 
	
	while(!done)
	{
			
		if (Score>highscore) highscore=Score;
		if (Score<0) Score=0;
		Time=(int)SDL_GetTicks();
		CurrentFrame=(Time/MPF)%4;
		if (Play==1&&Lives<=0){Lives=GLives;Score=GScore;highscore=0;KillAll();}
		if (Play==1) title=0;
		
		if (Time-updatetime>MPU)
		{
			if (DEBUG) printf("Updating");
			updatetime=Time;
			if (title) HARD=1; else HARD=0;
			if (Play==1&&Lives>0) MeteoGenerator();
			if (Play==0&&Lives<=0) MeteoGenerator();
			list=Player;
			while (list->next!=NULL) 
			{
				(*list->update)(list);
				if (list==NULL) break;
				if (list->next!=NULL) list=list->next;
			}
			(*list->update)(list);
			if (DEBUG) printf(".\n");
			DestroyThing(NULL); 		// this emptys the death waiting room
		}
		if (Lives<=0)
		{
			Score=highscore;
		}
					
		if (Time-movetime>MPM)
		{
			if (DEBUG) printf("Moving");
			movetime=Time;
			list=Player;
			while (list->next!=NULL) 
			{
				(*list->move)(list);
				list=list->next;
			}
			(*list->move)(list);
			if (DEBUG) printf(".\n");
		}
		
		if (Time-drawtime>MPD)
		{
			if (DEBUG) printf("Drawing");
			drawtime=Time;
			DrawBackground(); 
			list=Player;
			while (list->next!=NULL) 
			{
				(*list->draw)(list);
				list=list->next;
			}
			(*list->draw)(list);
			if (title) PutString(Screen,WIDTH/2-TextWidth("A S T R O B L A S T   2 0 0 0")/2,
			HEIGHT-GROUND,"A S T R O B L A S T   2 0 0 0");
			if (NewLevel>0)
			{
				PutString(Screen,0,0,"Level");
				PutString(Screen,TextWidth("Level "),0,itoa(Level));
				NewLevel--;
			}
			if (Play==0) PutString(Screen,0,HEIGHT-50,"Press Enter");
			if (Lives<=0&&!title) PutString(Screen,WIDTH/2-TextWidth("GAME OVER")/2,GROUND/2,"GAME OVER");
			_score=itoa(Score); _lives=itoa(Lives);
			PutString(Screen,WIDTH-TextWidth("_score")-100,HEIGHT-50,_score);
			PutString(Screen,WIDTH-50,HEIGHT-50,_lives);
			SDL_UpdateRect(Screen,0,0,0,0);
			
		
			if (DEBUG) printf(".\n");
		}
		
		if (Time-shoottime>MPS&&Firing&&Play)
		{
			if (DEBUG) printf ("Shooting");
			shoottime=Time;
			CreateBullet(Player,UP,F_SPEED,Player->x,Player->y-3);
			if (CHEAT)
			{
				CreateBullet(Player,UPLEFT,F_SPEED,Player->x,Player->y-3);
				CreateBullet(Player,UPRIGHT,F_SPEED,Player->x,Player->y-3);
			}
			if (CHEAT2)
			{
				CreateBullet(Player,UP,F_SPEED,Player->x+20,Player->y);
				CreateBullet(Player,UP,F_SPEED,Player->x-20,Player->y);
			}
			if (DEBUG) printf(".\n");
		}
		
			
		while (SDL_PollEvent(&event))   
		{
			switch (event.type) 
			{
				case SDL_MOUSEMOTION:
					Player->x=event.motion.x;
					if (_2D) Player->y=event.motion.y;
					break;
				case SDL_MOUSEBUTTONDOWN:
					Firing=1;
					break;
				case SDL_MOUSEBUTTONUP:
					Firing=0;
					break;
				
				case SDL_KEYDOWN:
					if (event.key.keysym.sym==SDLK_LEFT) 
					{
						Player->dir=LEFT;
					 	Player->speed=P_SPEED;
					}
					if (event.key.keysym.sym==SDLK_RIGHT) 
					{
						Player->dir=RIGHT;
						Player->speed=P_SPEED;
					}
					if (event.key.keysym.sym==SDLK_SPACE) Firing=1; 
					if (event.key.keysym.sym==SDLK_ESCAPE) done=1; 
					if (event.key.keysym.sym==SDLK_RETURN&&!Play) 
					{
						Play=1; 
						Player->health=100;
						KillAll();
					} 
					if (event.key.keysym.sym==SDLK_BACKSPACE) SDL_SaveBMP(Screen,"screenshot.bmp");
					if (event.key.keysym.sym==SDLK_TAB) NewLevel=30; 
					 
					break; 
				case SDL_KEYUP:
					if (event.key.keysym.sym==SDLK_LEFT) Player->speed=0;
					if (event.key.keysym.sym==SDLK_RIGHT) Player->speed=0;
					if (event.key.keysym.sym==SDLK_SPACE) Firing=0;
					break; 
				case SDL_QUIT:
					done = 1;
					break;
				default:
					break;
				
			}
			
		}
		
	}

}


void InitGame(void)
{
	
	Play=0;
	Score=GScore;
	Lives=0;
	Time=0; Level=1;
	Firing=0; NewLevel=0;
	Death=NULL;
	Player=(Thing*)calloc(1,sizeof(Thing));
	Player->x=STARTX;
	Player->y=STARTY;
	Player->prev=NULL;
	Player->next=NULL;
	Player->health=100;
	Player->type=PLAYER;
	Player->dir=LEFT;
	Player->speed=0;
	Player->update=UpdatePlayer;
	Player->move=Move;
	Player->draw=Draw;
	Player->image=(Animation*)calloc(1,sizeof(Animation));
	for (int i=0;i<4;i++) Player->image->frame[i]=Sprite[0];

}
	
void DrawBackground(void)
{
	// Ain't gonna draw anything for now just fill it with black
	SDL_FillRect(Screen,NULL,Background);
	// Even though there is no background it still updates the entire screen every frame as if there were one
	// This might not be the best possible method for something that doesn't scroll
}

void MeteoGenerator(void)
{
	int type, speed, x;
	
	x=(rand()%(Screen->w-(MARGIN*2)))+MARGIN;
	
	if (HARD) 
	{
		if (rand()%10!=0) return;
		type=rand()%2;
		if (rand()%15==0) type=STAR;
		if (rand()%30==0) type=SEEKER;
		speed=rand()%15+7;
		
	}	
	else if (Score>=99999&&CRUSH) 
	{
		type=rand()%4;
		speed=rand()%50+1;
	}
		
	else if (Score>=99999) 
	{
		
		if (CHEAT==1) CRUSH=1; 	
		if (CHEAT2==1) CHEAT=1;
		CHEAT2=1;
		Lives=10;
		Score=0;
		Level=1;
		KillAll();
		NewLevel=30;
	}	
	
	
	else if (Score>=99999-6543) 
	{
		type=STAR;
		speed=2;
	
	}	
	
	else if (Score>=50000)
	{
		Score+=500;
		Lives=10-(Score/10000);
		return;
	}
	
	else if (Score>=36600) 
	{
		if (rand()%4!=0) return;
		type=SEEKER;
		speed=3;
	}
	
		
	else if (Score>=36500) 
	{
		if (rand()%30!=0) return;
		type=BMETEO;
		speed=40;
	}
	
	else if (Score>=35000) 
	{
		if (rand()%3!=0) return;
		type=BMETEO;
		speed=3;
	}
	
	
	
	else if (Score>=30000) 
	{
		if (Level<6) {NewLevel=30; Lives++; Level=6;}
			
		type=LMETEO;
		speed=1;
	
	}	
	
	else if (Score>=10000)
	{
		if (Level<5) {NewLevel=30; Lives++; Level=5;}
	
		if (rand()%6!=0) return;
		type=rand()%2+2;
		speed=rand()%20+10;
	
	}	
	
	else if (Score>=9600)
	{
		if (Level<4) {NewLevel=30; Lives++; Level=4;}
		
	
		if (Score<9900)
		{
			if (rand()%2!=0) return;
			type=1;
			speed=rand()%10+1;
		}
		else 
		{
			if (rand()%4!=0) return;
			type=0;
			speed=rand()%25+10;
		}
			
	}
	else if (Score>=3500)
	{
		if (Level<3) {NewLevel=30; Lives++; Level=3;}
		
		if (rand()%7!=0) return;
		type=rand()%2+1;
		if (rand()%20==0) type=STAR;
		if (Score>9500) type=LMETEO;
		speed=rand()%20+10;
	
	}	
	
	else if (Score>=1000)
	{
		if (Level<2) {NewLevel=30; Lives++;Level=2; }
		
		if (rand()%10!=0) return;
		type=rand()%2;
		if (rand()%30==0) type=STAR;
		if (rand()%50==0) type=SEEKER;
		speed=rand()%15+7;
	}
	else  
	{
		
		if (rand()%20!=0) return;
		type=rand()%2;
		speed=rand()%10+5;
	}	
	
	
	switch (type)
	{
		case LMETEO:
			CreateLMeteo(Player,DOWN,speed,x,0);
			break;
		case BMETEO:
			CreateBMeteo(Player,DOWN,speed,x,0);
			break;
		case SEEKER:
			CreateSeeker(Player,DOWNLEFT,P_SPEED/2,x,0);
			break;
		case STAR:
			CreateStar(Player,DOWN,speed/2,x,0);
			break;
	}		
	return;	
}	

int LoadSprites(void) 
{
	int i;
	SDL_Surface *temp;
		
	Sprite[0]=SDL_LoadBMP("bmp/Player.bmp");
	Sprite[1]=SDL_LoadBMP("bmp/Shoot.bmp");
	Sprite[2]=SDL_LoadBMP("bmp/BMeteo.bmp");
	Sprite[3]=SDL_LoadBMP("bmp/LMeteo.bmp");
	Sprite[4]=SDL_LoadBMP("bmp/Seeker1.bmp");
	Sprite[5]=SDL_LoadBMP("bmp/Seeker2.bmp");
	Sprite[6]=SDL_LoadBMP("bmp/Seeker3.bmp");
	Sprite[7]=SDL_LoadBMP("bmp/Seeker4.bmp");
	Sprite[8]=SDL_LoadBMP("bmp/Star1.bmp");
	Sprite[9]=SDL_LoadBMP("bmp/Star2.bmp");
	Sprite[10]=SDL_LoadBMP("bmp/Star3.bmp");
	Sprite[11]=SDL_LoadBMP("bmp/Star4.bmp");
	

	for (i=0;i<MAXFRAMES;i++) 
	{
		SDL_SetColorKey(Sprite[i],(SDL_SRCCOLORKEY|SDL_RLEACCEL),0);
		if (Sprite[i]==NULL) return -1;
		temp=SDL_DisplayFormat(Sprite[i]);
		SDL_FreeSurface(Sprite[i]);
		if (temp==NULL) 
		{
			fprintf(stderr, "Couldn't convert Sprite: %s\n",SDL_GetError());
	 		return -1;
		}
		Sprite[i]=temp;
	}
	AFont=SDL_LoadBMP("font.bmp");
	SDL_SetColorKey(AFont,(SDL_SRCCOLORKEY|SDL_RLEACCEL),0);
	if (AFont==NULL) return -1;
	temp=SDL_DisplayFormat(AFont);
	SDL_FreeSurface(AFont);
	if (temp==NULL) 
	{
		fprintf(stderr, "Couldn't convert Font: %s\n",SDL_GetError());
		return -1;
	}
	AFont=temp;

	return 0;
}



int main(int argc, char *argv[])
{
	Uint8  video_bpp;
	Uint32 videoflags;
	int i, cursor;
	
	
	cursor=0; GScore=0; GLives=10; 
	if ( SDL_Init(SDL_INIT_VIDEO) < 0 ) 
	{
		fprintf(stderr, "Couldn't initialize SDL: %s\n",SDL_GetError());
		exit(1);
	}
	atexit(SDL_Quit);
	video_bpp=BPP;
	videoflags = SDL_SWSURFACE;
	for(i=1;i<argc;i++) 
	{
		
		if ( strcmp(argv[i], "-bpp") == 0 ) video_bpp = atoi(argv[++i]);
		else if ( strcmp(argv[i], "-width") == 0 ) WIDTH = atoi(argv[++i]);
		else if ( strcmp(argv[i], "-height") == 0 ) HEIGHT = atoi(argv[++i]);
		else if ( strcmp(argv[i], "-fps") == 0 ) 
		{
			MPD = 1000/atoi(argv[++i]);
			MPF=MPD; MPM=MPD; MPU=MPD;
		} 
		else if ( strcmp(argv[i], "-score") == 0 ) GScore = atoi(argv[++i]);
		else if ( strcmp(argv[i], "-lives") == 0 ) GLives = atoi(argv[++i]);
		else if ( strcmp(argv[i], "-fullscreen") == 0 ) {videoflags |= SDL_FULLSCREEN;cursor=0;}
		else if ( strcmp(argv[i], "-2d") == 0 ) _2D=1;
		else if ( strcmp(argv[i], "-debug") == 0 ) DEBUG=1;
		else if ( strcmp(argv[i], "-iworshipdavid") == 0 ) CRUSH=1;
		else if ( strcmp(argv[i], "-davidisgod") == 0 ) CHEAT=1;
		else if ( strcmp(argv[i], "-piottisgod") == 0 ) CHEAT2=2;
		else 
		{
			fprintf(stderr,"Usage: %s [-bpp N] [-width N] [-height N] [-fps N] [-fullscreen]\n",argv[0]);
			exit(1);
		}
	}

	SDL_ShowCursor(cursor);
	STARTX=WIDTH/2;
	GROUND=HEIGHT*80/100;
	STARTY=GROUND-10;
	MARGIN=WIDTH*5/100;
	
	
	if ((Screen=SDL_SetVideoMode(WIDTH,HEIGHT,video_bpp,videoflags)) == NULL ) 
	{
		fprintf(stderr, "Couldn't set video mode: %s\n", SDL_GetError());
		exit(2);
	}

	Background=SDL_MapRGB(Screen->format,0,0,0);
	
	if (LoadSprites()==-1)
	{
		fprintf(stderr, "Couldn't load Sprites: %s\n", SDL_GetError());
		exit(2);
	}	
	
	InitFont(AFont);
	SDL_WM_SetCaption("Astroblast 2000 by David Piott",NULL);
	
	InitGame();
	MainLoop();
	for (i=0;i<MAXFRAMES;i++) SDL_FreeSurface(Sprite[i]);
	exit(0);
}


